package de.intevation.flys.artifacts.model;

import java.util.HashMap;
import java.util.Map;
import java.util.Set;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import org.apache.log4j.Logger;

import de.intevation.artifacts.CallMeta;


public class WSPLGENCalculation extends Calculation {

    private static final Logger log = Logger.getLogger(WSPLGENCalculation.class);

    protected Map<Integer, String> errors;
    protected Map<Integer, String> warnings;


    public WSPLGENCalculation() {
        errors   = new HashMap<Integer, String>();
        warnings = new HashMap<Integer, String>();
    }


    public void addError(Integer key, String msg) {
        log.debug("New error: (" + key + ") " + msg);
        errors.put(key, msg);
    }


    public void addWarning(Integer key, String msg) {
        log.debug("New warning: (" + key + ") " + msg);
        warnings.put(key, msg);
    }


    public int numErrors() {
        return errors.size();
    }


    public int numWarnings() {
        return warnings.size();
    }


    public void toXML(Document document, CallMeta meta) {
        Element root = document.createElement("problems");

        if (numErrors() > 0) {
            Set<Map.Entry<Integer, String>> entrySet = errors.entrySet();

            for (Map.Entry<Integer, String> entry: entrySet) {
                Element problem = document.createElement("problem");
                problem.setAttribute("error", String.valueOf(entry.getKey()));
                problem.setTextContent(entry.getValue());

                root.appendChild(problem);
            }
        }

        if (numWarnings() > 0) {
            Set<Map.Entry<Integer, String>> entrySet = warnings.entrySet();

            for (Map.Entry<Integer, String> entry: entrySet) {
                Element problem = document.createElement("problem");
                problem.setAttribute("error", String.valueOf(entry.getKey()));
                problem.setTextContent(entry.getValue());

                root.appendChild(problem);
            }
        }

        document.appendChild(root);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
